OC.L10N.register(
    "settings",
    {
    "Private" : "Private",
    "Local" : "Lokale",
    "Federated" : "Federated",
    "Verify" : "Verifiko",
    "Verifying …" : "Duke verifikuar ...",
    "Unable to change password" : "S’arrin të ndryshojë fjalëkalimin",
    "Very weak password" : "Fjalëkalim shumë i dobët",
    "Weak password" : "Fjalëkalim i dobët",
    "So-so password" : "Fjalëkalim çka",
    "Good password" : "Fjalëkalim i mirë",
    "Strong password" : "Fjalëkalim i fortë",
    "Groups" : "Grupe",
    "{actor} changed your password" : "{actor} ndryshoi fjalëkalimin tuaj ",
    "You changed your password" : "Ju ndëruat fjalëkalimin",
    "Your password was reset by an administrator" : "Fjalëkalimi juaj është rivendosur nga administratori",
    "{actor} changed your email address" : "{actor} ndërroi emailin tuaj",
    "You changed your email address" : "Ju ndryshuat  adresën e emailit tuaj",
    "Your email address was changed by an administrator" : "Adresa juaj e email-it është ndryshuar nga një administrator",
    "Security" : "Siguria",
    "You successfully logged in using two-factor authentication (%1$s)" : "Ju keni hyrë me sukses duke përdorur autentifikimin me dy faktorë ( %1$s )",
    "A login attempt using two-factor authentication failed (%1$s)" : "Një përpjekje e identifikimit me anë të autentifikimit me dy faktorë dështoi ( %1$s )",
    "Your <strong>password</strong> or <strong>email</strong> was modified" : "<strong>fjalëkalimi</strong> ose <strong>emaili</strong> juaj është modifikuar",
    "Settings" : "Rregullimet",
    "Wrong password" : "Fjalëkalim i gabuar",
    "Saved" : "U ruajt",
    "Authentication error" : "Gabim mirëfilltësimi",
    "Wrong admin recovery password. Please check the password and try again." : "Fjalëkalim i gabuar rikthimesh për përgjegjësin. Ju lutemi, kontrolloni fjalëkalimin dhe provoni përsëri.",
    "Administrator documentation" : "Dokumentim për përgjegjës",
    "User documentation" : "Dokumentim për përdoruesit",
    "Invalid SMTP password." : "Fjalëkalim SMTP i pavlefshëm",
    "Email setting test" : "Test i konfigurimeve të Email-it",
    "Well done, %s!" : "U krye, %s!",
    "If you received this email, the email configuration seems to be correct." : "Nëse keni marrë këtë email, konfigurimi i email-it duket të jetë i saktë.",
    "Email could not be sent. Check your mail server log" : "Email nuk mund të dërgohej. Kontrolloni logun e serverit tuaj të postës",
    "A problem occurred while sending the email. Please revise your settings. (Error: %s)" : "Ndodhi një gabim gjatë dërgimit të email-it. Ju lutemi, rishikoni rregullimet tuaja. (Error: %s)",
    "Invalid account" : "Llogari e pavlefshme",
    "Invalid mail address" : "Adresë email e pavlefshme",
    "Settings saved" : "Konfigurimet u ruajtën",
    "Unable to change full name" : "S’arrin të ndryshojë emrin e plotë",
    "Unable to change email address" : "Nuk mund të ndryshohet adresa e email-it",
    "In order to verify your Twitter account, post the following tweet on Twitter (please make sure to post it without any line breaks):" : "Në mënyrë që të verifikoni llogarinë tuaj në Twitter, postojeni tweet-in e mëposhtme në Twitter (ju lutemi sigurohuni që ta postoni atë pa asnjë ndërprerje rrjeshti):",
    "In order to verify your Website, store the following content in your web-root at '.well-known/CloudIdVerificationCode.txt' (please make sure that the complete text is in one line):" : "Në mënyrë që të verifikoni faqen tuaj të internetit, ruani përmbajtjen e mëposhtme në rrënjën tuaj të internetit në '.well-known / CloudIdVerificationCode.txt' (ju lutemi sigurohuni që teksti i plotë të jetë në një vijë):",
    "%1$s changed your password on %2$s." : "%1$s ju ka ndryshuar fjalëkalmin në %2$s.",
    "Your password on %s was changed." : "Fjalëkalimi juaj në %s u ndryshua. ",
    "Your password on %s was reset by an administrator." : "Fjalëkalimi juaj në %s u rivendos nga një administrator.",
    "Password for %1$s changed on %2$s" : "Fjalëkalimi për %1$s ndryshojë në %2$s",
    "Password changed for %s" : "Fjalëkalimi ndryshojë për %s",
    "If you did not request this, please contact an administrator." : "Nëse ju nuk e keni kërkuar këtë, ju lutem kontaktoni një administrator.",
    "Your email address on %s was changed." : "Adresa e juaj e email-it në %s u ndryshua",
    "Your email address on %s was changed by an administrator." : "Adresa e juaj e email-it në %s u ndryshua nga një adminstrator.",
    "Email address for %1$s changed on %2$s" : "Adresa e email-it për %1$s ndryshojë në %2$s",
    "Email address changed for %s" : "Adresa e email-it ndryshojë për %s",
    "The new email address is %s" : "Adresa e re e email-it është %s",
    "Your %s account was created" : "Llogaria juaj %s u krijua",
    "Welcome aboard" : "Mirë se vini në bord",
    "Welcome aboard %s" : "Mirë se vini në bord %s",
    "Set your password" : "Vendos fjalëkalimin tënd",
    "Go to %s" : "Shko tek %s",
    "Install Client" : "Instalo Klient",
    "Apps" : "Aplikacione",
    "Personal" : "Personale",
    "Users" : "Përdoruesit",
    "Additional settings" : "Konfigurime shtesë",
    "Basic settings" : "Konfigurime bazike",
    "Sharing" : "Ndarje me të tjerët",
    "Calendar" : "Kalendar",
    "Personal info" : "Informacion personal",
    "Email server" : "Shërbyes email-esh",
    "Background jobs" : "Punët në background",
    "Unlimited" : "E pakufizuar",
    "Verifying" : "Duke verifikuar",
    "Disabled" : "I/E çaktivizuar",
    "PHP does not seem to be setup properly to query system environment variables. The test with getenv(\"PATH\") only returns an empty response." : "PHP-ja nuk duket të jetë ngritur si duhet për të kërkuar ndryshore mjedisi sistemi. Testi me getenv(\"PATH\") kthen vetëm një përgjigje të zbrazët.",
    "Your database does not run with \"READ COMMITTED\" transaction isolation level. This can cause problems when multiple actions are executed in parallel." : "Baza juaj e të dhënave nuk ekzekutohet me nivelin \"READ COMMITED\" e izolimit për ndërveprimet. Kjo mund të shkaktojë probleme, kur kryhen paralelisht disa veprime njëherësh.",
    "Enable" : "Aktivizoje",
    "None" : "Asnjë",
    "Allow apps to use the Share API" : "Lejoni aplikacionet të përdorin API Share",
    "Allow resharing" : "Lejo rindarje",
    "Allow sharing with groups" : "Lejoni ndarje me grupe",
    "Restrict users to only share with users in their groups" : "Përdoruesve kufizoju të ndajnë gjëra vetëm me përdorues në grupin e tyre",
    "Allow public uploads" : "Lejo ngarkime publike",
    "Always ask for a password" : "Gjithmonë pyet për një fjalëkalim",
    "Enforce password protection" : "Detyro mbrojtje me fjalëkalim",
    "Enforce expiration date" : "Detyro datë skadimi",
    "This text will be shown on the public link upload page when the file list is hidden." : "Ky tekst do të shfaqet në linkun publik të faqes së ngarkuar kur lista e skedarit të jetë e fshehur.",
    "Limit to groups" : "Kufizo grupet",
    "Save changes" : "Ruaj ndryshimet",
    "Remove" : "Hiqe",
    "Featured" : "I paraqitur",
    "Icon" : "Ikonë",
    "Name" : "Emër",
    "Version" : "Version",
    "Level" : "Nivel",
    "Actions" : "Veprimet",
    "No apps found for your version" : "S’u gjetën aplikacione për versionin tuaj",
    "Type" : "Tipi",
    "Display Name" : "Trego Emrin",
    "Learn more" : "Mësoni më shumë",
    "Confirm" : "Konfirmo",
    "Cancel" : "Anuloje",
    "Description" : "Përshkrim",
    "View in store" : "Shiko në dyqan",
    "Visit website" : "Vizitoni sajtin",
    "Admin documentation" : "Dokumentim për përgjegjësit",
    "Developer documentation" : "Dokumentim për zhvillues",
    "Details" : "Detaje",
    "All" : "Krejt",
    "No results" : "Asnjë rezultat",
    "Update to {version}" : "Përditëso në {version}",
    "This app has no minimum Nextcloud version assigned. This will be an error in the future." : "Ky aplikacion nuk ka të caktuar një minimum versioni të Nextcloud. Ky do të jetë një gabim në të ardhmen.",
    "This app has no maximum Nextcloud version assigned. This will be an error in the future." : "Ky aplikacion nuk ka të caktuar një maksimum versioni të Nextcloud. Ky do të jetë një gabim në të ardhmen.",
    "This app cannot be installed because the following dependencies are not fulfilled:" : "Ky aplikacion s’mund të instalohet, ngaqë për të nuk plotësohen varësitë vijuese:",
    "Categories" : "Kategoritë",
    "Resources" : "Burimet",
    "Documentation" : "Dokumentacioni",
    "Report a bug" : "Njoftoni një të metë",
    "Request feature" : "Kërkoni një karakteristikë",
    "Ask questions or discuss" : "Pyesni ose diskutoni",
    "Rate" : "Vlerësoj",
    "Changelog" : "Katalogu i ndryshimeve",
    "Google Chrome for Android" : "Google Chrome për Android",
    "This session" : "Ky sesion",
    "Allow filesystem access" : "Lejo aksesin e sistemit të skedarëve",
    "Rename" : "Rename",
    "Revoke" : "Anulo",
    "Device" : "Pajisje",
    "Last activity" : "Aktiviteti i fundit",
    "Web, desktop and mobile clients currently logged in to your account." : "Klientë në rrjet, desktop dhe celular kanë hyrë aktualisht në  llogarinë tuaj.",
    "Error while creating device token" : "Gabim gjatë krijimit të token-ëve të pajisjejeve",
    "App name" : "Emër aplikacioni",
    "Create new app password" : "Krijoni fjalëkalim aplikacioni të ri",
    "Login" : "Hyrje",
    "Password" : "Fjalëkalim",
    "Server-side encryption" : "Fshehtëzim më anë shërbyesi",
    "Server-side encryption makes it possible to encrypt files which are uploaded to this server. This comes with limitations like a performance penalty, so enable this only if needed." : "Enkriptimi nga ana e serverit bën të mundur enkriptimin e skedarëve të ngarkuar në këtë server. Kjo vjen me kufizime si një ndëshkim për performancën, prandaj e lejoni këtë vetëm nëse është e nevojshme.",
    "Enable server-side encryption" : "Aktivizo fshehtëzim më anë të shërbyesit",
    "No encryption module loaded, please enable an encryption module in the app menu." : "S’ka të ngarkuar modul fshehtëzimi, ju lutemi, aktivizoni një modul fshehtëzimi që nga menuja e aplikacionit.",
    "Select default encryption module:" : "Përzgjidhni modul parazgjedhje fshehtëzimi:",
    "Enable encryption" : "Aktivizoni fshehtëzim",
    "Once encryption is enabled, all files uploaded to the server from that point forward will be encrypted at rest on the server. It will only be possible to disable encryption at a later date if the active encryption module supports that function, and all pre-conditions (e.g. setting a recover key) are met." : "Pasi të jetë aktivizuar fshehtëzimi, krejt kartelat e ngarkuara te shërbyesi nga kjo pikë e tutje do të fshehtëzohen pasi të jenë depozituar në shërbyes. Çaktivizimi i fshehtëzimit në një datë të mëvonshme do të jetë i mundur vetëm nëse moduli aktiv i fshehtëzimeve e mbulon këtë funksion, dhe nëse plotësohen krejt parakushtet (p.sh. caktimi i një kyçi rimarrjesh).",
    "Encryption alone does not guarantee security of the system. Please see documentation for more information about how the encryption app works, and the supported use cases." : "Vetëm shifrimi nuk garaton sigurinë e sistemit. Ju lutem shikoni dokumentimin për më shumë informacion mbi mënyrën si applikacioni punon, dhe përdorimin e rasteve të suportuara.",
    "Be aware that encryption always increases the file size." : "Kini parasysh që fshehtëzimi e rrit gjithnjë madhësinë e kartelës.",
    "It is always good to create regular backups of your data, in case of encryption make sure to backup the encryption keys along with your data." : "Është gjithmonë ide e mirë të krijohen kopjeruajtje të rregullta të të dhënave tuaja, në rast fshehtëzimi sigurohuni që bëni kopjeruajtje të kyçeve të fshehtëzimit, tok me të dhënat tuaja.",
    "This is the final warning: Do you really want to enable encryption?" : "Ky është sinjalizimi përfundimtar: Doni vërtet të aktivizohet fshehtëzimi?",
    "Submit" : "Dërgo",
    "Remove group" : "Hiq grupin",
    "Current password" : "Fjalëkalimi i tanishëm",
    "New password" : "Fjalëkalimi i ri",
    "Change password" : "Ndrysho fjalëkalimin",
    "Picture provided by original account" : "Foto e prurë nga llogaria origjinale",
    "No email address set" : "S’është caktuar adresë email",
    "Help translate" : "Ndihmoni në përkthim",
    "Your phone number" : "Numri juaj i telefonit",
    "Your website" : "Website-i juaj",
    "Add" : "Shto",
    "Create" : "Krijo",
    "Change" : "Ndrysho",
    "Delete" : "Fshij",
    "Display name" : "Shfaq emrin",
    "Email" : "Email",
    "Quota" : "Kuota",
    "Language" : "Gjuhë",
    "Avatar" : "Avatari",
    "Group admin for" : "Administratori i  grupit për",
    "Storage location" : "Vendndodhje Depozite",
    "Last login" : "Hyrja e fundit",
    "Account actions" : "Veprimet e llogarisë",
    "{size} used" : "{size} e përdorur",
    "Delete account" : "Fshij llogarinë",
    "Done" : "U bë",
    "Edit" : "Përpuno",
    "Show last login" : "Shfaq hyrjen e fundit",
    "Send email" : "Dërgo email",
    "Default quota" : "Kuota Parazgjedhje",
    "Adding your device …" : "Shtoni pajisjen tuaj ...",
    "Unnamed device" : "Paisje pa emër",
    "As admin you can fine-tune the sharing behavior. Please see the documentation for more information." : "Si admin ju mund të rregulloni mirë sjelljen e ndarjes. Ju lutem shih dokumentacionin për më shumë informacion.",
    "Admins" : "Administratorë",
    "Group name" : "Emër grupi",
    "Sending…" : "dërgim",
    "Email sent" : "Email-i u dërgua",
    "Location" : "Vendndodhje",
    "Profile picture" : "Foto profili",
    "About" : "Rreth ",
    "Full name" : "Emër i plotë",
    "Phone number" : "Numri i telefonit",
    "Website" : "Faqe web-i",
    "Your apps" : "Aplikacionet tuaja ",
    "Active apps" : "Aplikacionet aktive",
    "Disabled apps" : "Aplikacionet pa aftësi ",
    "Updates" : "Përditësime",
    "App bundles" : "Pako e aplikacionit ",
    "Hide" : "Fshihe",
    "Disable" : "Çaktivizoje",
    "Unknown" : "I panjohur",
    "Never" : "Kurrë",
    "The app has been enabled but needs to be updated. You will be redirected to the update page in 5 seconds." : "Aplikacioni është aktivizuar, por lyp të përditësohet. Do të ridrejtoheni te faqja e përditësimeve brenda 5 sekondash.",
    "Error" : "Gabim",
    "Forum" : "Forum",
    "SSL" : "SSL",
    "Open documentation" : "Hapni dokumentimin",
    "It is important to set up this server to be able to send emails, like for password reset and notifications." : "Është e rëndësishme të ngrini këtë server për të qenë në gjendje të dërgoni email, si për rivendosjen e fjalëkalimeve dhe për njoftimet.",
    "Send mode" : "Mënyrë dërgimi",
    "Encryption" : "Fshehtëzim",
    "From address" : "Nga adresa",
    "Server address" : "Adresë shërbyesi",
    "Port" : "Portë",
    "Authentication" : "Mirëfilltësim",
    "Authentication required" : "Lypset mirëfilltësim",
    "Credentials" : "Kredenciale",
    "SMTP Password" : "Fjalëkalim SMTP",
    "Save" : "Ruaj",
    "Security & setup warnings" : "Sinjalizime sigurie & rregullimi",
    "All checks passed." : "I kaloi krejt kontrollet.",
    "Developed by the {communityopen}Nextcloud community{linkclose}, the {githubopen}source code{linkclose} is licensed under the {licenseopen}AGPL{linkclose}." : "Zhvilluar nga {communityopen}komuniteti Nextcloud {linkclose},  {githubopen}kodi i hapur{linkclose} iështë licensuar sipar {licenseopen}AGPL{linkclose}.",
    "Like our Facebook page" : "Pëlqeni faqen tonë në Facebook",
    "Check out our blog" : "Shikoni blogun tonë",
    "Subscribe to our newsletter" : "Abonohu në gazeten tonë",
    "New user" : "Përdorues i ri",
    "Username" : "Emër përdoruesi",
    "User backend" : "Program klient i përdoruesit",
    "Name your device" : "Emërtoni pajisjen tuaj",
    "Follow us on Twitter" : "Na ndiqni në Twitter"
},
"nplurals=2; plural=(n != 1);");
